#
# spec file for package python-tzlocal
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define modname tzlocal
Name:           python-%{modname}
Version:        2.0.0
Release:        bp153.1.20
Summary:        tzinfo object for the local timezone
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/regebro/tzlocal
Source:         https://github.com/regebro/tzlocal/archive/%{version}.tar.gz
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytz
BuildArch:      noarch
%python_subpackages

%description
This Python module returns a tzinfo object with the local timezone information
under Unix and Win-32. It requires pytz, and returns pytz tzinfo objects.

This module attempts to fix a glaring hole in pytz, that there is no way to get
the local timezone information, unless you know the zoneinfo name, and under
several Linux distros that’s hard or impossible to figure out.

Also, with Windows different timezone system using pytz isn’t of much use unless
you separately configure the zoneinfo timezone name.

With tzlocal you only need to call get_localzone() and you will get a tzinfo
object with the local time zone info. On some Unices you will still not get to
know what the timezone name is, but you don’t need that when you have the tzinfo
file. However, if the timezone name is readily available it will be used.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py test

%files %{python_files}
%license LICENSE.txt
%doc README.rst CHANGES.txt
%{python_sitelib}/%{modname}
%{python_sitelib}/%{modname}-%{version}-py*.egg-info

%changelog
* Wed Mar 11 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without py2
* Wed Jul 31 2019 pgajdos@suse.com
- version update to 2.0.0
  Major differences since 1.5.1
  .............................
  - When no time zone configuration can be find, tzlocal now return UTC.
    This is a major difference from 1.x, where an exception would be raised.
    This change is because Docker images often have no configuration at all,
    and the unix utilities will then default to UTC, so we follow that.
  - If tzlocal on Unix finds a timezone name in a /etc config file, then
    tzlocal now verifies that the timezone it fouds has the same offset as
    the local computer is configured with. If it doesn't, something is
    configured incorrectly. (Victor Torres, regebro)
  - Get timezone via Termux `getprop` wrapper on Android. It's not officially
    supported because we can't test it, but at least we make an effort.
    (Jean Jordaan)
  Minor differences and bug fixes
  ...............................
  - Skip comment lines when parsing /etc/timezone. (Edward Betts)
  - Don't load timezone from current directory. (Gabriel Corona)
  - Now verifies that the config files actually contain something before
    reading them. (Zackary Welch, regebro)
  - Got rid of a BytesWarning (Mickaël Schoentgen)
  - Now handles if config file paths exists, but are directories.
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github archive as per upstream recommendation:
  * the pypi archive fails tests due to wrong file->symlink conversions
- Update to 1.5.1:
  * increased test coverage.
  * No longer treats macOS as special, but as a unix.
  * get_windows_info.py is renamed to update_windows_mappings.py
  * Windows mappings now also contain mappings from deprecated zoneinfo names.
    (Preston-Landers, regebro)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Sep 12 2018 Sean Marlow <sean.marlow@suse.com>
- Fix fdupes, broke python3 package (was symlink to python2)
- Fix check, only tested against python2
- Move license
* Mon Oct  2 2017 sean.marlow@suse.com
- Update source tarball location.
* Mon Aug 28 2017 bear454@opensuse.org
- Update to version 1.4
  - Relicensed upstream as MIT
  - Dropping support for Python versions 2.5, 3.1, 3.2
  - adding support for Python 3.6
  - Closes stdout and stderr to get rid of ResourceWarnings
  - Added support for /var/db/zoneinfo
  - Tests failed if TZ was set in the environment.
  - Replaces os.popen() with subprocess.Popen()
  - Systemd stores no time zone name, forcing us to look at the
    name of the file that localtime symlinks to.
* Tue Jul 11 2017 rjschwei@suse.com
- Convert to singlespec build
* Mon Sep 14 2015 ms@suse.com
- Package required in SLE12 due to fate#319400
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Tue Jun  9 2015 jkeil@suse.de
- Reworked spec file
  * Bump version
  * Use github upstream url
  * Improve description and summary
  * Use tarball instead of zip
  * Minimize %%files section
* Thu Nov  6 2014 seiler@b1-systems.de
- corrected license
- added check section with python test
* Thu Nov  6 2014 seiler@b1-systems.de
- added required pytz dependency
- enhanced truncated description and add URL to source
* Wed Nov  5 2014 seiler@b1-systems.de
- inital commit
